@@ -1,8 +1,6 @@
 import logging
 from dotenv import load_dotenv
-from get_pop.definitions import DIR_DATA
 from get_pop.logs.config.logging import logs_config
-from get_pop.modules.helper.misc import delete_dir_contents
 from get_pop.modules.helper.time import utc_now
 from get_pop.modules.init.pandas_opts import pandas_opts
 from datetime import datetime
@@ -24,7 +22,6 @@ def init_program(package_name: str = None) -> datetime:
 
     # init logging
     program_start_time = utc_now()
-    timezone = program_start_time.tzinfo
     logs_config()
     if package_name:
         logging.info(f"Initializing {package_name}")
